"""
Nano WebSocket Client Library

This library provides a client for interacting with Nano node WebSocket API.
"""

from nanows.api import NanoWebSocketClient

__version__ = "2.0.0"

__all__ = ["NanoWebSocketClient"]
